@@ -6,12 +6,17 @@ import urllib.request
 
 
 class VirtualEmbed:
-    def __init__(self, bot_avatar: str = ""):
-        self._title = ""
-        self._description = ""
-        self._color = ""
+    def __init__(self, bot_avatar: str = "", title:str="", description:str="", color:str=""):
+        self._title = title
+        self._description = description
+        self._color = color
         self._bot_name = "Clyde"
 
+        self._thumbnail = None
+        self._image = None
+        self._author_name = None
+        self._author_icon = None
+
         self.bot_avatar = bot_avatar
         self.json = {
             'embed': {
@@ -83,6 +88,7 @@ class VirtualEmbed:
                 "url": image_url
             }
         }
+        self._thumbnail = image_url
         self.get_embed_json()["embed"].update(thumbnail)
 
     def set_image(self, image_url: str):
@@ -91,6 +97,7 @@ class VirtualEmbed:
                 "url": image_url
             }
         }
+        self._image = image_url
         self.get_embed_json()["embed"].update(thumbnail)
 
     def set_author(self, name: str, icon_url: str = None):
@@ -100,6 +107,8 @@ class VirtualEmbed:
                 "icon_url": icon_url
             }
         }
+        self._author_name = name
+        self._author_icon = icon_url
         self.get_embed_json()["embed"].update(author)
 
 
